@@ -5,16 +5,16 @@
 
 #ifdef GCOV_COMPILE
 
-void __gcov_flush();
-SEXP pkgcache__gcov_flush() {
+void __gcov_dump(void);
+SEXP pkgcache__gcov_flush(void) {
   REprintf("Flushing coverage info\n");
-  __gcov_flush();
+  (void) __gcov_dump();
   return R_NilValue;
 }
 
 #else
 
-SEXP pkgcache__gcov_flush() {
+SEXP pkgcache__gcov_flush(void) {
   return R_NilValue;
 }
 
