@@ -1,7 +1,6 @@
 
 test_that("bioconductor$get_repos", {
-  skip_if_offline()
-  skip_on_cran()
+  setup_fake_apps()
   bioc_version <- bioconductor$get_bioc_version("3.3.0")
   repos <- bioconductor$get_repos(bioc_version)
   expect_true("BioCextra" %in% names(repos))
@@ -11,8 +10,7 @@ test_that("bioconductor$get_repos", {
 })
 
 test_that("bioconductor$.internal$get_matching_bioc_version", {
-  skip_if_offline()
-  skip_on_cran()
+  setup_fake_apps()
   rvers <- c("2.15", "2.16", "3.1.0", "3.1.1", "3.2.0", "3.3.1", "3.4.0",
              "3.5.1")
   expect_silent(lapply(rvers, bioconductor$get_matching_bioc_version))
